# QuAESiT

<h2>A framework for easy development of agent-based models</h2>
<p>Quaesit stands for <b>Qu</b>ick <b>a</b>nd <b>E</b>asy <b>Si</b>mulation <b>T</b>ools. This package is based on the concepts and architecture of platforms such as Netlogo, as well as other Python packages for agent-based modelling, namely mesa. It is also based on the architecture of ExPaND, a model developed by me for simulating human migrations in South America.</p>

## Documentation and Tutorial

<a href="http://jgregoriods.github.io/quaesit">jgregoriods.github.io/quaesit</a>
